@@ -420,7 +420,7 @@ addFilesFromDir <- function(dir, pattern = "*.txt$"){
   oldDir <- getwd()
   setwd(dir)
   Files <- list.files(pattern = pattern)
-  Contents <- lapply(Files, function(x) paste(readLines(x, warn = FALSE), collasep = "\n"))
+  Contents <- lapply(Files, function(x) paste(readLines(x, warn = FALSE), collapse = "\n"))
   names(Contents) <- Files
   write.FileList(Contents)
   on.exit(setwd(oldDir))
